@@ -622,6 +622,18 @@ END
    cmd_raw($handle,"${sudo}cpan Task::Catalyst::Tutorial",'__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING DBIx::Class
+
+########################################
+END
+   cmd_raw($handle,
+      'perl -MCPAN -e \'CPAN::Shell->notest('.
+      '"install","DBIx::Class")\'',
+      '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING DBIx::Class::Schema::Loader
@@ -885,6 +897,18 @@ END
            '__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING Catalyst::Helper::Model::DBIC::Schema
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Helper::Model::DBIC::Schema",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING Catalyst::View::Email
@@ -1079,7 +1103,7 @@ END
    ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
       "model DB DBIC::Schema FullAutoAPI::Schema create=static ".
       "components=TimeStamp,PassphraseColumn ".
-      "moniker_map='{ users => "Users" }' dbi:SQLite:db/fullautoapi.db",
+      "moniker_map='{ users => \"Users\" }' dbi:SQLite:db/fullautoapi.db",
       '__display__');
    my $user_path="./lib/FullAutoAPI/Schema/Result/Users.pm";
    $ad="%NL%__PACKAGE__->add_columns(%NL%".
